pub struct MaxDataFrame {
pub maximum_data: VarInt,
}Expand description
A MAX_DATA frame following Section 19.9.
Informs the peer of the maximum amount of data that can be sent on the connection as a whole.
Fields
maximum_data: VarIntThe maximum amount of data that can be sent on the entire connection, in units of bytes.
Implementations